@@ -377,6 +377,28 @@ class HealpixBase:
         else:
             return hp.pix2ang(self.nside, pix, nest = self.is_nested)
             
+    def pix2vec(self, pix):
+        """
+        Return a vector corresponding to the center of a pixel
+        
+        Args:
+            pix (int or array)
+
+        Return:
+            array: Size (3,N)
+        """
+
+        if self.is_moc:
+
+            pix,order = hmap.uniq2nest(self.pix2uniq(pix))
+
+            nside = hp.order2nside(order)
+
+            return hp.pix2vec(nside, pix, nest = True)
+            
+        else:
+            return hp.pix2vec(self.nside, pix, nest = self.is_nested)
+            
     def ang2pix(self, theta, phi):
         """
         Get the pixel (as used in []) that contains a given coordinate
