@@ -16,8 +16,6 @@ from astropy.table import Table
 import numpy as np
 from numpy import array, log2, sqrt
 
-from pathlib import Path
-
 import collections
 
 from .healpix_base import HealpixBase
@@ -146,8 +144,6 @@ class HealpixMap(HealpixBase):
             HealpixMap
         """
 
-        filename = Path(filename)
-        
         with fits.open(filename) as hdul:
 
             hdu = hdul[hdu]
@@ -270,7 +266,7 @@ class HealpixMap(HealpixBase):
 
         hdulist = fits.HDUList([fits.PrimaryHDU(), hdu])
 
-        hdulist.writeto(Path(filename), overwrite = overwrite)
+        hdulist.writeto(filename, overwrite = overwrite)
         
     
     @classmethod
